@@ -71,8 +71,7 @@ expr_corr_test <- function(data,
                            ...) {
 
   # make sure both quoted and unquoted arguments are supported
-  x <- rlang::ensym(x)
-  y <- rlang::ensym(y)
+  c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
 
   #------------------------ dataframe -------------------------------------
 
